// eslint-disable-next-line object-curly-newline
import { Avatar, Box, Button, IconButton, TextField, Typography } from '@material-ui/core';
import CloseIcon from '@material-ui/icons/Close';
import React, { Dispatch, SetStateAction } from 'react';
import { CustomModal } from './CustomModal';

type Dispatcher<S> = Dispatch<SetStateAction<S>>;

interface IProfileModalProps {
  isOpen: boolean;
  setIsOpen: Dispatcher<boolean>;
}

export const ProfileModal: React.FC<IProfileModalProps> = ({ isOpen, setIsOpen }) => {
  const onClose = (): void => {
    setIsOpen(false);
  };
  return (
    <CustomModal
      isOpen={isOpen}
      setIsOpen={setIsOpen}
      customStyle={{
        backgroundColor: '#EBEBEB',
        padding: '15px',
        width: '500px',
        borderRadius: '8px',
      }}
    >
      <Box
        fontWeight="fontWeightBold"
        display="flex"
        justifyContent="space-between"
        alignItems="center"
        pl={2}
      >
        <Typography variant="h5" component="h5">
          Profilom
        </Typography>
        <IconButton onClick={onClose}>
          <CloseIcon />
        </IconButton>
      </Box>
      <Box display="flex" justifyContent="center" my={3}>
        <Avatar alt="Profile image" variant="rounded" style={{ width: '200px', height: '200px' }} />
      </Box>
      <Box px={1} mt={2} mb={1}>
        <Box my={1}>
          <TextField
            label="Diákigazolvány szám"
            variant="outlined"
            color="secondary"
            fullWidth
            size="small"
            style={{ backgroundColor: 'white' }}
          />
        </Box>
        <Box my={1}>
          <TextField
            label="Szobaszám"
            variant="outlined"
            color="secondary"
            fullWidth
            size="small"
            style={{ backgroundColor: 'white' }}
          />
        </Box>
        <Box display="flex" justifyContent="flex-end" mt={3}>
          <Button variant="contained" onClick={onClose}>
            Mentés
          </Button>
        </Box>
      </Box>
    </CustomModal>
  );
};

export default ProfileModal;
